package adminkindboxservice

import (
	"context"

	entity "git.gocasts.ir/ebhomengo/niki/entity"
	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
)

func (s Service) Delete(ctx context.Context, req param.KindBoxDeleteRequest) (param.KindBoxDeleteResponse, error) {
	// TODO: Does business domain need to delete an kindbox ?
	const op = "adminkindboxservice.Delete"

	kb, gErr := s.repo.GetKindBox(ctx, req.KindBoxID)
	if gErr != nil {
		return param.KindBoxDeleteResponse{}, richerror.New(op).WithErr(gErr).WithKind(richerror.KindUnexpected)
	}
	if kb.Status != entity.KindBoxPendingSendStatus {
		return param.KindBoxDeleteResponse{}, richerror.New(op).WithMessage(errmsg.ErrorMsgInvalidStatus).WithKind(richerror.KindInvalid)
	}
	if kb.BenefactorID != req.BenefactorID {
		return param.KindBoxDeleteResponse{}, richerror.New(op).WithMessage(errmsg.ErrorMsgUserNotAllowed).WithKind(richerror.KindForbidden)
	}

	dErr := s.repo.DeleteKindBox(ctx, req.KindBoxID)
	if dErr != nil {
		return param.KindBoxDeleteResponse{}, richerror.New(op).WithErr(dErr).WithKind(richerror.KindUnexpected)
	}

	return param.KindBoxDeleteResponse{}, nil
}
